@@ -3,7 +3,6 @@ from graphene_django import DjangoObjectType
 from .models import Premium, PremiumMutation
 from core import prefix_filterset, ExtendedConnection
 from policy.schema import PolicyGQLType
-from payer.schema import PayerGQLType
 
 
 class PremiumGQLType(DjangoObjectType):
@@ -19,7 +18,6 @@ class PremiumGQLType(DjangoObjectType):
             "pay_type": ["exact"],
             "is_photo_fee": ["exact"],
             "receipt": ["exact", "icontains"],
-            **prefix_filterset("payer__", PayerGQLType._meta.filter_fields),
             **prefix_filterset("policy__", PolicyGQLType._meta.filter_fields)
         }
         connection_class = ExtendedConnection
